@@ -7,7 +7,7 @@ from contextlib import contextmanager
 
 import pytest
 from dagster.core.storage.pipeline_run import PipelineRunStatus
-from dagster.core.test_utils import poll_for_finished_run, poll_for_step_start
+from dagster.core.test_utils import environ, poll_for_finished_run, poll_for_step_start
 from dagster.utils.test.postgres_instance import postgres_instance_for_test
 from dagster.utils.yaml_utils import merge_yamls
 from dagster_docker.docker_run_launcher import DOCKER_IMAGE_TAG
@@ -17,8 +17,8 @@ from dagster_test.test_project import (
     get_buildkite_registry_config,
     get_test_project_docker_image,
     get_test_project_environments_path,
-    get_test_project_external_pipeline,
     get_test_project_recon_pipeline,
+    get_test_project_workspace_and_external_pipeline,
 )
 
 IS_BUILDKITE = os.getenv("BUILDKITE") is not None
@@ -41,8 +41,12 @@ def test_launch_docker_image_on_pipeline_config():
         "env_vars": [
             "AWS_ACCESS_KEY_ID",
             "AWS_SECRET_ACCESS_KEY",
+            "DOCKER_LAUNCHER_NETWORK",
         ],
-        "network": "container:test-postgres-db-docker",
+        "network": {"env": "DOCKER_LAUNCHER_NETWORK"},
+        "container_kwargs": {
+            "auto_remove": True,
+        },
     }
 
     if IS_BUILDKITE:
@@ -57,34 +61,40 @@ def test_launch_docker_image_on_pipeline_config():
         ]
     )
 
-    with docker_postgres_instance(
-        overrides={
-            "run_launcher": {
-                "class": "DockerRunLauncher",
-                "module": "dagster_docker",
-                "config": launcher_config,
+    with environ({"DOCKER_LAUNCHER_NETWORK": "container:test-postgres-db-docker"}):
+        with docker_postgres_instance(
+            overrides={
+                "run_launcher": {
+                    "class": "DockerRunLauncher",
+                    "module": "dagster_docker",
+                    "config": launcher_config,
+                }
             }
-        }
-    ) as instance:
-        recon_pipeline = get_test_project_recon_pipeline("demo_pipeline", docker_image)
-        run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(),
-            run_config=run_config,
-        )
+        ) as instance:
+            recon_pipeline = get_test_project_recon_pipeline("demo_pipeline", docker_image)
+            with get_test_project_workspace_and_external_pipeline(
+                instance, "demo_pipeline", container_image=docker_image
+            ) as (workspace, orig_pipeline):
 
-        external_pipeline = ReOriginatedExternalPipelineForTest(
-            get_test_project_external_pipeline("demo_pipeline", container_image=docker_image),
-            container_image=docker_image,
-        )
-        instance.launch_run(run.run_id, external_pipeline)
+                external_pipeline = ReOriginatedExternalPipelineForTest(
+                    orig_pipeline,
+                    container_image=docker_image,
+                )
+                run = instance.create_run_for_pipeline(
+                    pipeline_def=recon_pipeline.get_definition(),
+                    run_config=run_config,
+                    external_pipeline_origin=external_pipeline.get_external_origin(),
+                    pipeline_code_origin=external_pipeline.get_python_origin(),
+                )
+                instance.launch_run(run.run_id, workspace)
 
-        poll_for_finished_run(instance, run.run_id, timeout=60)
+                poll_for_finished_run(instance, run.run_id, timeout=60)
 
-        run = instance.get_run_by_id(run.run_id)
+                run = instance.get_run_by_id(run.run_id)
 
-        assert run.status == PipelineRunStatus.SUCCESS
+                assert run.status == PipelineRunStatus.SUCCESS
 
-        assert run.tags[DOCKER_IMAGE_TAG] == docker_image
+                assert run.tags[DOCKER_IMAGE_TAG] == docker_image
 
 
 def _check_event_log_contains(event_log, expected_type_and_message):
@@ -130,40 +140,45 @@ def test_terminate_launched_docker_run():
         }
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("hanging_pipeline", docker_image)
-        run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(),
-            run_config=run_config,
-        )
+        with get_test_project_workspace_and_external_pipeline(
+            instance, "hanging_pipeline", container_image=docker_image
+        ) as (workspace, orig_pipeline):
+            external_pipeline = ReOriginatedExternalPipelineForTest(
+                orig_pipeline,
+                container_image=docker_image,
+            )
 
-        run_id = run.run_id
+            run = instance.create_run_for_pipeline(
+                pipeline_def=recon_pipeline.get_definition(),
+                run_config=run_config,
+                external_pipeline_origin=external_pipeline.get_external_origin(),
+                pipeline_code_origin=external_pipeline.get_python_origin(),
+            )
 
-        external_pipeline = ReOriginatedExternalPipelineForTest(
-            get_test_project_external_pipeline("hanging_pipeline", container_image=docker_image),
-            container_image=docker_image,
-        )
-        instance.launch_run(run_id, external_pipeline)
+            run_id = run.run_id
 
-        poll_for_step_start(instance, run_id)
+            instance.launch_run(run_id, workspace)
 
-        assert instance.run_launcher.can_terminate(run_id)
-        assert instance.run_launcher.terminate(run_id)
+            poll_for_step_start(instance, run_id)
 
-        terminated_pipeline_run = poll_for_finished_run(instance, run_id, timeout=30)
-        terminated_pipeline_run = instance.get_run_by_id(run_id)
-        assert terminated_pipeline_run.status == PipelineRunStatus.CANCELED
+            assert instance.run_launcher.can_terminate(run_id)
+            assert instance.run_launcher.terminate(run_id)
 
-        run_logs = instance.all_logs(run_id)
+            terminated_pipeline_run = poll_for_finished_run(instance, run_id, timeout=30)
+            terminated_pipeline_run = instance.get_run_by_id(run_id)
+            assert terminated_pipeline_run.status == PipelineRunStatus.CANCELED
 
-        _check_event_log_contains(
-            run_logs,
-            [
-                ("PIPELINE_CANCELING", "Sending pipeline termination request"),
-                ("STEP_FAILURE", 'Execution of step "hanging_solid" failed.'),
-                ("PIPELINE_CANCELED", 'Execution of pipeline "hanging_pipeline" canceled.'),
-                ("ENGINE_EVENT", "Pipeline execution terminated by interrupt"),
-                ("ENGINE_EVENT", "Process for pipeline exited"),
-            ],
-        )
+            run_logs = instance.all_logs(run_id)
+
+            _check_event_log_contains(
+                run_logs,
+                [
+                    ("PIPELINE_CANCELING", "Sending pipeline termination request"),
+                    ("STEP_FAILURE", 'Execution of step "hanging_solid" failed.'),
+                    ("PIPELINE_CANCELED", 'Execution of pipeline "hanging_pipeline" canceled.'),
+                    ("ENGINE_EVENT", "Process for pipeline exited"),
+                ],
+            )
 
 
 def test_launch_docker_invalid_image():
@@ -197,19 +212,26 @@ def test_launch_docker_invalid_image():
         }
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("demo_pipeline")
-        run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(),
-            run_config=run_config,
-        )
-
-        external_pipeline = ReOriginatedExternalPipelineForTest(
-            get_test_project_external_pipeline("demo_pipeline")
-        )
-        with pytest.raises(
-            Exception,
-            match=re.escape("Docker image name _invalid_format_image is not correctly formatted"),
+        with get_test_project_workspace_and_external_pipeline(instance, "demo_pipeline") as (
+            workspace,
+            orig_pipeline,
         ):
-            instance.launch_run(run.run_id, external_pipeline)
+            external_pipeline = ReOriginatedExternalPipelineForTest(orig_pipeline)
+
+            run = instance.create_run_for_pipeline(
+                pipeline_def=recon_pipeline.get_definition(),
+                run_config=run_config,
+                external_pipeline_origin=external_pipeline.get_external_origin(),
+                pipeline_code_origin=external_pipeline.get_python_origin(),
+            )
+
+            with pytest.raises(
+                Exception,
+                match=re.escape(
+                    "Docker image name _invalid_format_image is not correctly formatted"
+                ),
+            ):
+                instance.launch_run(run.run_id, workspace)
 
 
 def test_launch_docker_image_on_instance_config():
@@ -245,16 +267,21 @@ def test_launch_docker_image_on_instance_config():
         }
     ) as instance:
         recon_pipeline = get_test_project_recon_pipeline("demo_pipeline")
-        run = instance.create_run_for_pipeline(
-            pipeline_def=recon_pipeline.get_definition(),
-            run_config=run_config,
-        )
+        with get_test_project_workspace_and_external_pipeline(instance, "demo_pipeline") as (
+            workspace,
+            orig_pipeline,
+        ):
+            external_pipeline = ReOriginatedExternalPipelineForTest(orig_pipeline)
 
-        external_pipeline = ReOriginatedExternalPipelineForTest(
-            get_test_project_external_pipeline("demo_pipeline")
-        )
-        instance.launch_run(run.run_id, external_pipeline)
+            run = instance.create_run_for_pipeline(
+                pipeline_def=recon_pipeline.get_definition(),
+                run_config=run_config,
+                external_pipeline_origin=external_pipeline.get_external_origin(),
+                pipeline_code_origin=external_pipeline.get_python_origin(),
+            )
 
-        poll_for_finished_run(instance, run.run_id, timeout=60)
+            instance.launch_run(run.run_id, workspace)
 
-        assert instance.get_run_by_id(run.run_id).status == PipelineRunStatus.SUCCESS
+            poll_for_finished_run(instance, run.run_id, timeout=60)
+
+            assert instance.get_run_by_id(run.run_id).status == PipelineRunStatus.SUCCESS
